==> rgeostat_0.1-3.tar.gz: rgeostat/src/krige_tiles.h <==
#include <R.h>
#include <Rinternals.h>

void krige_tiles(double *xsw,
		double *ysw,
		double *xne,
		double *yne,
		double *angle,
		int *nx,
		int *ny,                 
		//                  nz=as.integer(nz), 
		int *ntx,
		int *nty,
		// nt=as.integer(nt),
		double *dx,
		double *dy,
		int *itx,
		int *ity,
		// ipt=as.integer(ipt),   
		double *xg,
		double *yg,
		double *zg,
		double *varg,
		int *dog,
		// xgwork=double(nz),
		// ygwork=double(nz),
		double *lon,
		double *lat,
		double *z,
		int *extrap,
		int *n,
		int *covtype,
		double *covpar,
		//	    double *covmat=as.double(covmat),
		//      ldcov=as.integer(n),
		//      c0vec=double(n),
		//      ldc0vec=as.integer(n),
		 //     double *cov0,
		//      extcov=as.integer(0), # no external cov matrix
		int *trend,
		int *ntrend,
		double *rsearch,
		int *nsearch,
		int *nsmin,
		int *nsmax,
		//      fwork=double(n*ntrend),
		//      ldfwrk=as.integer(n),
		//      f0work=double(ntrend),
		//      dist=double(n),
		//      indsnb=integer(n),
		//      indsna=integer(n),
		//      indsrt=integer(n),
		//      kwork=double((n+ntrend)*(n+ntrend)),
		//      nkwork=as.integer(n+ntrend),
		//      rhswork=double(n+ntrend),
		//      ipiv=integer(n+ntrend),
		int *mode,
		//      mu=double(ntrend),
		//      lambda=double(n),
		//      ldlmbd=as.integer(n),
		//  x0=double(ipt),
                //  y0=double(ipt),
                //  z0=double(ipt),
                //  do0=integer(ipt),
                //  inddo=integer(ipt),
                //  var0=double(ipt),
            int *bits,
		int *ierr);

F77_NAME(krgtil)(double *xsw, 
		 double *ysw, 
		 double *xne, 
		 double *yne, 
		 double *angle, 
		 int *nx, 
		 int *ny, 
		 int *nz, 
		 int *ntx,
		 int *nty,
		 int *nt,
		 double *dx, 
		 double *dy,
		 int *itx,
		 int *ity,
		 int *ipt,
		 double *xg, 
		 double *yg, 
		 double *zg, 
		 double *varg, 
		 int *dog,
		 double *xgwork,
		 double *ygwork,
		 double *lon, 
		 double *lat, 
		 double *z, 
		 int *extrap, 
		 int *n, 
		 int *covtype, 
		 double *covpar, 
		 double *covmat, 
		 int *ldcov, 
		 double *c0vec, 
		 int *ldc0, 
		 double *cov0,
		 int *extcov, 
		 int *trend, 
		 int *ntrend, 
		 double *rsearch, 
		 int *nsearch, 
		 int *nsmin, 
		 int *nsmax, 
		 double *fwork, 
		 int *ldfwrk, 
		 double *f0work, 
		 double *dist, 
		 int *indsnb, 
		 int *indsna, 
		 int *indsrt, 
		 double *kwork, 
		 int *nkwork, 
		 double *rhswork, 
		 int *ipiv, 
		 int *mode, 
		 double *mu, 
		 double *lambda, 
		 int *ldlmbd,
		 double *x0,
		 double *y0,
		 double *z0,
		 int *do0,
		 int *inddo,
		 double *var0,
		 int *bits, 
		 int *ierr);

==> rgeostat_0.1-4.tar.gz: rgeostat/src/krige_tiles.h <==
#include <R.h>
#include <Rinternals.h>

void krige_tiles(double *xsw,
		double *ysw,
		double *xne,
		double *yne,
		double *angle,
		int *nx,
		int *ny,                 
		int *ntx,
		int *nty,
		double *dx,
		double *dy,
		int *itx,
		int *ity,
		double *xg,
		double *yg,
		double *zg,
		double *varg,
		int *dog,
		double *lon,
		double *lat,
		double *z,
		int *extrap,
		int *n,
		int *covtype,
		double *covpar,
		int *trend,
		int *ntrend,
		double *rsearch,
		int *nsearch,
		int *nsmin,
		int *nsmax,
		int *mode,
            int *bits,
		int *ierr);

void F77_NAME(krgtil)(double *xsw, 
		 double *ysw, 
		 double *xne, 
		 double *yne, 
		 double *angle, 
		 int *nx, 
		 int *ny, 
		 int *nz, 
		 int *ntx,
		 int *nty,
		 int *nt,
		 double *dx, 
		 double *dy,
		 int *itx,
		 int *ity,
		 int *ipt,
		 double *xg, 
		 double *yg, 
		 double *zg, 
		 double *varg, 
		 int *dog,
		 double *xgwork,
		 double *ygwork,
		 double *lon, 
		 double *lat, 
		 double *z, 
		 int *extrap, 
		 int *n, 
		 int *covtype, 
		 double *covpar, 
		 double *covmat, 
		 int *ldcov, 
		 double *c0vec, 
		 int *ldc0, 
		 double *cov0,
		 int *extcov, 
		 int *trend, 
		 int *ntrend, 
		 double *rsearch, 
		 int *nsearch, 
		 int *nsmin, 
		 int *nsmax, 
		 double *fwork, 
		 int *ldfwrk, 
		 double *f0work, 
		 double *dist, 
		 int *indsnb, 
		 int *indsna, 
		 int *indsrt, 
		 double *kwork, 
		 int *nkwork, 
		 double *rhswork, 
		 int *ipiv, 
		 int *mode, 
		 double *mu, 
		 double *lambda, 
		 int *ldlmbd,
		 double *x0,
		 double *y0,
		 double *z0,
		 int *do0,
		 int *inddo,
		 double *var0,
		 int *bits, 
		 int *ierr);
